@@ -1,7 +1,11 @@
 package Sah::Schemas::Float;
 
-our $DATE = '2020-06-04'; # DATE
-our $VERSION = '0.011'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-09-22'; # DATE
+our $DIST = 'Sah-Schemas-Float'; # DIST
+our $VERSION = '0.012'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas for various floating types
@@ -18,10 +22,12 @@ Sah::Schemas::Float - Sah schemas for various floating types
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2020-06-04.
+This document describes version 0.012 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2022-09-22.
 
 =head1 SAH SCHEMAS
 
+The following schemas are included in this distribution:
+
 =over
 
 =item * L<inf|Sah::Schema::inf>
@@ -117,6 +123,41 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Float>.
 
+=head1 SEE ALSO
+
+L<Sah> - schema specification
+
+L<Data::Sah> - Perl implementation of Sah
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2019, 2018 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Float>
@@ -125,21 +166,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<Sah> - specification
-
-L<Data::Sah>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
